# - Config file for the ${PROJECT_NAME} package
# It defines the following variables
#  ${PROJECT_NAME}_INCLUDE_DIRS - include directory for ${PROJECT_NAME}
#  ${PROJECT_NAME}_LIBRARIES    - all libraries to link against (warning, may be slower than just specify the used libs)
#  ${PROJECT_NAME}_ALL_FOUND    - set to TRUE if all requested COMPONENTS are specified (see below), false otherwise
#  ${PROJECT_NAME}_MISSING_TOOLKITS - when ${PROJECT_NAME}_ALL_FOUND is FALSE, contains a list of missing toolkits
#
# If COMPONENTS is specified in the find_package() commands, it contains
# a list of toolkit modules which are requested.  For each component,
# ${PROJECT_NAME}_<toolkit>_FOUND is set to TRUE or FALSE.
# Warning: <toolkit> is case-sensitive, for instance TKernel.
# For convenience, ${PROJECT_NAME}_ALL_FOUND is set to TRUE if all
# toolkits are found, otherwise FALSE.  In the latter case,
# ${PROJECT_NAME}_MISSING_TOOLKITS contains the list of missing toolkits.
 
# Tell the user project where to find our headers and libraries
GET_FILENAME_COMPONENT(SELF_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

SET(OCE_INCLUDE_DIRS "${SELF_DIR}/../../include/oce")
SET(OCE_LIBRARIES "TKernel;TKMath;TKAdvTools;TKG2d;TKG3d;TKGeomBase;TKBRep;TKGeomAlgo;TKTopAlgo;TKPrim;TKBO;TKHLR;TKMesh;TKShHealing;TKXMesh;TKBool;TKFillet;TKFeat;TKOffset;TKService;TKV2d;TKV3d;TKOpenGl;TKMeshVS;TKNIS;TKVoxel;TKCDF;PTKernel;TKLCAF;FWOSPlugin;TKPShape;TKBinL;TKXmlL;TKPLCAF;TKTObj;TKShapeSchema;TKStdLSchema;TKCAF;TKBin;TKXml;TKPCAF;TKBinTObj;TKXmlTObj;TKStdSchema;TKSTL;TKXSBase;TKSTEPBase;TKIGES;TKSTEPAttr;TKSTEP209;TKSTEP;TKVRML;TKXCAF;TKXCAFSchema;TKXmlXCAF;TKBinXCAF;TKXDEIGES;TKXDESTEP;TKDraw;TKTopTest;TKViewerTest;TKXSDRAW;TKDCAF;TKXDEDRAW;TKTObjDRAW;DRAWEXE")
INCLUDE("${SELF_DIR}/OCE-libraries.cmake")

SET(OCE_ALL_FOUND true)
IF(OCE_FIND_COMPONENTS)
	FOREACH(toolkit ${OCE_FIND_COMPONENTS})
		IF(TARGET ${toolkit})
			SET(OCE_${toolkit}_FOUND true)
		ELSE(TARGET ${toolkit})
			SET(OCE_ALL_FOUND false)
			SET(OCE_${toolkit}_FOUND false)
			SET(OCE_MISSING_TOOLKITS ${OCE_MISSING_TOOLKITS} ${toolkit})
			IF(OCE_FIND_REQUIRED)
				MESSAGE(FATAL_ERROR "OCE ${toolkit} not available.")
			ENDIF(OCE_FIND_REQUIRED)
		ENDIF(TARGET ${toolkit})
	ENDFOREACH(toolkit ${OCE_FIND_COMPONENTS})
ENDIF(OCE_FIND_COMPONENTS)
